==> qtjambi-multimedia-debuginfo-linux-x64-5.15.18.jar: sources/QtJambiMultimedia/QAbstractAudioOutput_shell.h <==
#ifndef QABSTRACTAUDIOOUTPUT_SHELL_H
#define QABSTRACTAUDIOOUTPUT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimedia/qaudiosystem.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qiodevice.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtMultimedia/qaudio.h>
#include <QtMultimedia/qaudioformat.h>
#include <QtJambi/RegistryAPI>


class QAbstractAudioOutput_shell : public QAbstractAudioOutput, public QtJambiShellInterface
{
public:
    QAbstractAudioOutput_shell();
    ~QAbstractAudioOutput_shell() override;

    int bufferSize() const override;
    int bytesFree() const override;
    QString category() const override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    qint64 elapsedUSecs() const override;
    QAudio::Error error() const override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QAudioFormat format() const override;
    int notifyInterval() const override;
    int periodSize() const override;
    qint64 processedUSecs() const override;
    void reset() override;
    void resume() override;
    void setBufferSize(int value0) override;
    void setCategory(const QString& arg__1) override;
    void setFormat(const QAudioFormat& fmt0) override;
    void setNotifyInterval(int milliSeconds0) override;
    void setVolume(qreal arg__1) override;
    QIODevice* start() override;
    void start(QIODevice* device0) override;
    QAudio::State state() const override;
    void stop() override;
    void suspend() override;
    void timerEvent(QTimerEvent* event0) override;
    qreal volume() const override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAbstractAudioOutput_access : public QAbstractAudioOutput
{
    jint __qt_bufferSize(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_bytesFree(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_category(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jlong __qt_elapsedUSecs(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_error(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_format(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_notifyInterval(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_periodSize(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jlong __qt_processedUSecs(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_reset(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_resume(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_setBufferSize_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint value0);
    void __qt_setCategory_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring arg__1);
    void __qt_setFormat_cref_QAudioFormat(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID fmt0);
    void __qt_setNotifyInterval_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint milliSeconds0);
    void __qt_setVolume_qreal(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jdouble arg__1);
    jobject __qt_start(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_start_QIODevice_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID device0);
    jint __qt_state(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_stop(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_suspend(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jdouble __qt_volume(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QABSTRACTAUDIOOUTPUT_SHELL_H

==> qtjambi-multimedia-debuginfo-linux-x64-5.15.20.jar: sources/QtJambiMultimedia/QAbstractAudioOutput_shell.h <==
#ifndef QABSTRACTAUDIOOUTPUT_SHELL_H
#define QABSTRACTAUDIOOUTPUT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimedia/qaudiosystem.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qiodevice.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtMultimedia/qaudio.h>
#include <QtMultimedia/qaudioformat.h>
#include <QtJambi/RegistryAPI>


class QAbstractAudioOutput_shell : public QAbstractAudioOutput, public QtJambiShellInterface
{
public:
    QAbstractAudioOutput_shell();
    ~QAbstractAudioOutput_shell() override;

    int bufferSize() const override;
    int bytesFree() const override;
    QString category() const override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    qint64 elapsedUSecs() const override;
    QAudio::Error error() const override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QAudioFormat format() const override;
    int notifyInterval() const override;
    int periodSize() const override;
    qint64 processedUSecs() const override;
    void reset() override;
    void resume() override;
    void setBufferSize(int value0) override;
    void setCategory(const QString& arg__1) override;
    void setFormat(const QAudioFormat& fmt0) override;
    void setNotifyInterval(int milliSeconds0) override;
    void setVolume(qreal arg__1) override;
    QIODevice* start() override;
    void start(QIODevice* device0) override;
    QAudio::State state() const override;
    void stop() override;
    void suspend() override;
    void timerEvent(QTimerEvent* event0) override;
    qreal volume() const override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAbstractAudioOutput_access : public QAbstractAudioOutput
{
    jint __qt_bufferSize_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_bytesFree_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_category_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jlong __qt_elapsedUSecs_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_error_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_format_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_notifyInterval_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_periodSize_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jlong __qt_processedUSecs_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_reset(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_resume(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_setBufferSize_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint value0);
    void __qt_setCategory_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring arg__1);
    void __qt_setFormat_cref_QAudioFormat(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID fmt0);
    void __qt_setNotifyInterval_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint milliSeconds0);
    void __qt_setVolume_qreal(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jdouble arg__1);
    jobject __qt_start(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_start_QIODevice_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID device0);
    jint __qt_state_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_stop(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_suspend(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jdouble __qt_volume_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QABSTRACTAUDIOOUTPUT_SHELL_H
